#!/bin/bash
# SALOME_MECA V2017 - Environnement file for the prerequisites and tools

export ROOT_SALOME="/home/lgarelli/salome_meca/V2017.0.2"
export LC_NUMERIC=C

# To be sure to display icons in Gnome, we use the Gnome Configuration tool
gconfTool=`which gconftool-2`
if test -n "$gconfTool"; then
  $gconfTool --type boolean --set /desktop/gnome/interface/buttons_have_icons true
  $gconfTool --type boolean --set /desktop/gnome/interface/menus_have_icons true
fi

export SALOME_PLUGINS_PATH="${ROOT_SALOME}/plugins":${SALOME_PLUGINS_PATH}

if test -d "${ROOT_SALOME}/modules"; then
  export MODULES_ROOT_DIR="${ROOT_SALOME}/modules"
fi

if test ! -d "${ROOT_SALOME}/prerequisites"; then
  echo "=========================================="
  echo "Error: SALOME prerequisites path not found"
  echo "=========================================="
  exit 1
fi
export PREREQUISITES_ROOT_DIR="${ROOT_SALOME}/prerequisites"

if test ! -d "${ROOT_SALOME}/tools"; then
  echo "=================================="
  echo "Error: SALOME tools path not found"
  echo "=================================="
  exit 1
fi
export TOOLS_ROOT_DIR="${ROOT_SALOME}/tools"

export DEBIANFORSALOME=${PREREQUISITES_ROOT_DIR}/debianForSalome
export LD_LIBRARY_PATH=${DEBIANFORSALOME}/lib:/lib64:${LD_LIBRARY_PATH}

#------ tcl ------
export TCLDIR="${PREREQUISITES_ROOT_DIR}/Tcl-8513"   # export needed by Code_Aster
export PATH=${TCLDIR}/bin:$PATH
export LD_LIBRARY_PATH=${TCLDIR}/lib:$LD_LIBRARY_PATH
export TCL_LIBRARY=${TCLDIR}/lib/tcl8.5

#------ tk ------
export TKDIR="${PREREQUISITES_ROOT_DIR}/Tk-8513"   # export needed by Code_Aster
export PATH=${TKDIR}/bin:$PATH
export LD_LIBRARY_PATH=${TKDIR}/lib:$LD_LIBRARY_PATH
export TK_LIBRARY=${TKDIR}/lib/tk8.5

#------ python ------
export PYTHONHOME="${PREREQUISITES_ROOT_DIR}/Python-2710"
export PYTHONSTARTUP=${PYTHONHOME}/pythonrc.py
export PYTHON_INCLUDE=${PYTHONHOME}/include/python2.7
export PATH=${PYTHONHOME}/bin:${PATH}
export LD_LIBRARY_PATH=${PYTHONHOME}/lib:${LD_LIBRARY_PATH}
export PYTHONPATH=${PYTHONHOME}/lib/python2.7/site-packages:${PYTHONPATH}
# Temporary added for New Geom, to be removed after
# new geom environment variables have been made
# conform with SALOME variables
export PYTHON_ROOT_DIR=$PYTHONHOME

#------ sip ------
export SIP_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Sip-418"
export PATH=${SIP_ROOT_DIR}/bin:${PATH}
export PYTHONPATH=${SIP_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}
export LD_LIBRARY_PATH=${SIP_ROOT_DIR}/lib/python2.7/site-packages:${LD_LIBRARY_PATH}

#------ tix ------
export LD_LIBRARY_PATH="${TCLDIR}/lib/Tix8.4.3":$LD_LIBRARY_PATH

#------ omniORB ------
export OMNIORB_DIR="${PREREQUISITES_ROOT_DIR}/Omniorb-416"
export PATH=${OMNIORB_DIR}/bin:$PATH
export PYTHONPATH=${OMNIORB_DIR}/lib/python2.7/site-packages:${PYTHONPATH}
export LD_LIBRARY_PATH=$OMNIORB_DIR/lib:$LD_LIBRARY_PATH

#------ hdf5 ------
export HDF5HOME="${PREREQUISITES_ROOT_DIR}/Hdf5-1814"
export PATH=${HDF5HOME}/bin:$PATH
export LD_LIBRARY_PATH=${HDF5HOME}/lib:${LD_LIBRARY_PATH}
export HDF5_DISABLE_VERSION_CHECK=1

#------ CGNS Library ------
CGNSHOME=${PREREQUISITES_ROOT_DIR}/Cgnslib-3134
export PATH=${CGNSHOME}/bin:$PATH
export LD_LIBRARY_PATH=${CGNSHOME}/lib:${LD_LIBRARY_PATH}

#------ togl ------
export LD_LIBRARY_PATH="${TCLDIR}/lib/Togl1.7":$LD_LIBRARY_PATH

#------- pygments ------
PYGMENTS_HOME="${PREREQUISITES_ROOT_DIR}/Pygments-202"
export PATH=${PYGMENTS_HOME}/bin:${PATH}
export PYTHONPATH=${PYGMENTS_HOME}/lib/python2.7/site-packages:${PYTHONPATH}

#------ Metis ------
export METISDIR="${PREREQUISITES_ROOT_DIR}/Metis_aster-510_aster1"    # export needed for compilation of medsplitter/partitinner
export PATH=${METISDIR}/bin:$PATH
export LD_LIBRARY_PATH=${METISDIR}/lib:${LD_LIBRARY_PATH}

#------ codeaster-frontend ------
export ASTER_ROOT="${TOOLS_ROOT_DIR}/Code_aster_frontend-20170"
export PATH=${ASTER_ROOT}/bin:${PATH}
export LD_LIBRARY_PATH=${ASTER_ROOT}/lib:$LD_LIBRARY_PATH
export PYTHONPATH=${ASTER_ROOT}/lib/python2.7/site-packages:$PYTHONPATH

#------ ECREVISSE_OLD  ------
export ECREVISSE_OLD_ROOT_DIR="${TOOLS_ROOT_DIR}/Ecrevisse_old-321"

#------ gibi ------
export GIBI_DIR=${TOOLS_ROOT_DIR}/Gibi-20008     # export necessaire au lien Code_Aster/outils/gibi
export PATH=${GIBI_DIR}:$PATH

#------ gmsh_bin ------
export GMSH_BIN_DIR=${PREREQUISITES_ROOT_DIR}/Gmsh_bin-2120Linux64/bin
export PATH=${GMSH_BIN_DIR}:$PATH

#------ HOMARD_ASTER  ------
export HOMARD_ASTER_ROOT_DIR="${TOOLS_ROOT_DIR}/Homard_aster-117_aster"
export PATH=${HOMARD_ASTER_ROOT_DIR}:$PATH

#------ Lapack ------
export LAPACKDIR=${PREREQUISITES_ROOT_DIR}/Lapack-350
export LD_LIBRARY_PATH="$LAPACKDIR/lib":${LD_LIBRARY_PATH}

#------ med fichier ------
export MED3HOME="${TOOLS_ROOT_DIR}/Medfichier-321"
export MEDFICHIER_INSTALL_DIR="${TOOLS_ROOT_DIR}/Medfichier-321"
export PATH=${MED3HOME}/bin:${PATH}
export LD_LIBRARY_PATH=${MED3HOME}/lib:${LD_LIBRARY_PATH}
export PYTHONPATH=${MED3HOME}/lib/python2.7/site-packages:${PYTHONPATH}

#------- mercurial ------
export MERCURIAL_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Mercurial-261"
export PATH=${MERCURIAL_ROOT_DIR}/bin:${PATH}
export PYTHONPATH=${MERCURIAL_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}

#------ Metis ------
export METISDIR="${PREREQUISITES_ROOT_DIR}/Metis-40"
export LD_LIBRARY_PATH=${METISDIR}/Lib:${LD_LIBRARY_PATH}

#------ MFRONT ------
export LD_LIBRARY_PATH="${PREREQUISITES_ROOT_DIR}/Mfront-TFEL300/lib":${LD_LIBRARY_PATH}
export PATH="${PREREQUISITES_ROOT_DIR}/Mfront-TFEL300/bin":"$PATH"
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Mfront-TFEL300/lib/python2.7/site-packages":$PYTHONPATH
export TFELHOME="${PREREQUISITES_ROOT_DIR}/Mfront-TFEL300"

#------ MFRONT_STABLE ------
export LD_LIBRARY_PATH="${PREREQUISITES_ROOT_DIR}/Mfront_stable-TFEL202/lib":${LD_LIBRARY_PATH}
export PATH="${PREREQUISITES_ROOT_DIR}/Mfront_stable-TFEL202/bin":"$PATH"

#------ miss3d ------
export MISS3D_DIR=${TOOLS_ROOT_DIR}/Miss3d-66_aster4     # export necessaire a Code_Aster/outils/run_miss3d
export PATH=${MISS3D_DIR}:$PATH

#------ Numpy ------
NUMPY_DIR="${PREREQUISITES_ROOT_DIR}/Numpy-192"
export PATH=${NUMPY_DIR}/bin:${PATH}
export PYTHONPATH=${NUMPY_DIR}/lib/python2.7/site-packages:${PYTHONPATH}

#------ Scotch ------
export SCOTCHDIR="${PREREQUISITES_ROOT_DIR}/Scotch-5111"    # export needed for compilation of medsplitter/partitionner
export PATH=${SCOTCHDIR}/bin:${PATH}

#------ MUMPS ------
export LD_LIBRARY_PATH="${PREREQUISITES_ROOT_DIR}/Mumps4-4100_aster3/SEQ/lib":${LD_LIBRARY_PATH}

#------ code_aster - Template environment_shell ------
export ASTER_OLDSTABLE="${TOOLS_ROOT_DIR}/Code_aster_oldstable-1280"
if [ -d /usr/lib/atlas-base/atlas ]; then
    if [ -z "$LD_LIBRARY_PATH" ]; then
        export LD_LIBRARY_PATH=/usr/lib/atlas-base/atlas
    else
        export LD_LIBRARY_PATH=/usr/lib/atlas-base/atlas:$LD_LIBRARY_PATH
    fi
fi


#------- docutils ------
export DOCUTILS_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Docutils-012"
export PATH=${DOCUTILS_ROOT_DIR}/bin:${PATH}
export PYTHONPATH=${DOCUTILS_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}

#------ freetype ------
FREETYPE_ROOT="${PREREQUISITES_ROOT_DIR}/Freetype-2411"
export PATH=${FREETYPE_ROOT}/bin:$PATH
export LD_LIBRARY_PATH=${FREETYPE_ROOT}/lib:${LD_LIBRARY_PATH}

#------ omniORBpy ------
export OMNIORBPY_DIR="${PREREQUISITES_ROOT_DIR}/Omniorbpy-36"
export PYTHONPATH=${OMNIORBPY_DIR}/lib/python2.7/site-packages:${PYTHONPATH}
export PYTHONPATH=${OMNIORBPY_DIR}/lib/python2.7/site-packages/omniidl_be:${PYTHONPATH}

#------ boost ---------
export BOOSTDIR="${PREREQUISITES_ROOT_DIR}/Boost-1520"  # For check_boost.m4
export BOOST_ROOT="$BOOSTDIR"   # For CGAL
export LD_LIBRARY_PATH=$BOOST_ROOT/lib:$LD_LIBRARY_PATH

#------ graphviz ------
GRAPHVIZHOME="${PREREQUISITES_ROOT_DIR}/Graphviz-2380"
export PATH=${GRAPHVIZHOME}/bin:${PATH}
export LD_LIBRARY_PATH=${GRAPHVIZHOME}/lib/graphviz:${GRAPHVIZHOME}/lib:${LD_LIBRARY_PATH}

#------ gl2ps ------
export GL2PS_INSTALL_DIR="${PREREQUISITES_ROOT_DIR}/Gl2ps-139svn20160620"
export LD_LIBRARY_PATH=${GL2PS_INSTALL_DIR}/lib:$LD_LIBRARY_PATH

#------ cppunit ------
export CPPUNIT_ROOT="${PREREQUISITES_ROOT_DIR}/Cppunit-1132"
export PATH=${CPPUNIT_ROOT}/bin:$PATH
export LD_LIBRARY_PATH=${CPPUNIT_ROOT}/lib:${LD_LIBRARY_PATH}

#---------- libBatch -------------------
export LIBBATCH_ROOT_DIR="${TOOLS_ROOT_DIR}/Libbatch-V2_3_1"
export LD_LIBRARY_PATH=${LIBBATCH_ROOT_DIR}/lib:${LD_LIBRARY_PATH}
export PYTHONPATH=$LIBBATCH_ROOT_DIR/lib/python2.7/site-packages:${PYTHONPATH}

#------- libxml2 -------
export LIBXML_DIR="${PREREQUISITES_ROOT_DIR}/Libxml2-290"
export PATH=${LIBXML_DIR}/bin:${PATH}
export LD_LIBRARY_PATH=${LIBXML_DIR}/lib:${LD_LIBRARY_PATH}
export PYTHONPATH=${LIBXML_DIR}/lib/python2.7/site-packages:${PYTHONPATH}
# Temporary added for New Geom, to be removed after
# new geom environment variables have been made
# conform with SALOME variables
export LIBXML2_ROOT_DIR=$LIBXML_DIR

#------- jinja ------
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Jinja-273/lib/python2.7/site-packages":${PYTHONPATH}

#------ FreeImage ------
FREEIMAGE_ROOT="${PREREQUISITES_ROOT_DIR}/Freeimage-3160p1"
export FreeImage_version=3.16.0
export LD_LIBRARY_PATH=${FREEIMAGE_ROOT}/lib:${LD_LIBRARY_PATH}

#------ TBB. ------
export LD_LIBRARY_PATH="${PREREQUISITES_ROOT_DIR}/Tbb-424/lib":${LD_LIBRARY_PATH}

#------ cas ------
export CASROOT="${PREREQUISITES_ROOT_DIR}/Occ-710p1"
export LD_LIBRARY_PATH=${CASROOT}/lib:${LD_LIBRARY_PATH}
# Variable for Foundation Classes :
export CSF_UnitsLexicon=${CASROOT}/src/UnitsAPI/Lexi_Expr.dat
export CSF_UnitsDefinition=${CASROOT}/src/UnitsAPI/Units.dat
# Variable for DataExchange :
export CSF_SHMessageStd=${CASROOT}/src/SHMessageStd
export CSF_SHMessage=${CASROOT}/src/SHMessage
export CSF_XSMessage=${CASROOT}/src/XSMessage
# Variable for Font :
export CSF_MDTVFontDirectory=${CASROOT}/src/FontMFT
export CSF_MDTVTexturesDirectory=${CASROOT}/src/Textures
# Needed for HYDRO module :
export CSF_StandardDefaults=${CASROOT}/src/StdResource
export CSF_PluginDefaults=${CASROOT}/src/StdResource
export CSF_StandardLiteDefaults=${CASROOT}/src/StdResource
export CSF_XmlOcafResource=${CASROOT}/src/XmlOcafResource
# Temporary added for New Geom, to be removed after
# new geom environment variables have been made
# conform with SALOME variables
export PATH=${CASROOT}:${PATH}

# ------ Qt -------------
export QTDIR="${PREREQUISITES_ROOT_DIR}/Qt-5611"
export PATH=${QTDIR}/bin:$PATH
export QT_PLUGIN_PATH=${QTDIR}/plugins
export LD_LIBRARY_PATH=${QTDIR}/lib:${LD_LIBRARY_PATH}
export QTVERSION=5
export LRELEASE=${QTDIR}/bin/lrelease
export QT_QPA_PLATFORM_PLUGIN_PATH=${QTDIR}/plugins/platforms

#-------PyQt ----------
export PYQT_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Pyqt-560"
export PYQT_SIPS=${PYQT_ROOT_DIR}/share/sip
export PYUIC=${PYQT_ROOT_DIR}/bin/pyuic5
export PYTHONPATH=${PYQT_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}
export PATH=${PYQT_ROOT_DIR}/bin:${PATH}

#------- Matplotlib ------
export MATPLOTLIB_HOME="${PREREQUISITES_ROOT_DIR}/Matplotlib-143"
export PYTHONPATH=${MATPLOTLIB_HOME}/lib/python2.7/site-packages:${PYTHONPATH}
export MPLCONFIGDIR="${HOME}/.config/salome/matplotlib-1.4.3" # Useful to avoid changing the config files used by the system matplotlib

#------ ParaView ------
export PVHOME="${PREREQUISITES_ROOT_DIR}/Paraview-v512_EDF"
export PATH=${PVHOME}/bin:$PATH
export PVVERSION=5.1
export PV_PLUGIN_PATH="$(readlink -f ${PVHOME}/lib/paraview-${PVVERSION}):${PV_PLUGIN_PATH}"
export LD_LIBRARY_PATH=${PVHOME}/lib/paraview-${PVVERSION}:$LD_LIBRARY_PATH
export PYTHONPATH=${PVHOME}/lib/paraview-${PVVERSION}:${PYTHONPATH}
export PYTHONPATH=${PVHOME}/lib/paraview-${PVVERSION}/site-packages:${PYTHONPATH}
export PYTHONPATH=${PVHOME}/lib/paraview-${PVVERSION}/site-packages/vtk:${PYTHONPATH}

export PYTHONPATH=${PVHOME}/lib/paraview-${PVVERSION}/site-packages/paraview/vtk:${PYTHONPATH}

#------ qwt ------
export QWTHOME="${PREREQUISITES_ROOT_DIR}/Qwt-612" # pour PARAVIS
export QWT_INCLUDES=${QWTHOME}/include
export LD_LIBRARY_PATH=${QWTHOME}/lib:${LD_LIBRARY_PATH}

# ------ Scipy ------
export PYTHONPATH="${PREREQUISITES_ROOT_DIR}/Scipy-0151/lib/python2.7/site-packages":${PYTHONPATH}

#------ MEDCoupling ------
export MEDCOUPLING_ROOT_DIR="${TOOLS_ROOT_DIR}/Medcoupling-V8_3_0"
export PATH=${MEDCOUPLING_ROOT_DIR}/bin:${PATH}
export LD_LIBRARY_PATH=${MEDCOUPLING_ROOT_DIR}/lib:${LD_LIBRARY_PATH}
export PYTHONPATH=${MEDCOUPLING_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}

#------ ASTERSTUDY module ------
export ASTERSTUDY_ROOT_DIR="${MODULES_ROOT_DIR}/ASTERSTUDY_201702"
# asrun
export PYTHONPATH=${ASTER_ROOT}/lib/python2.7/site-packages:${PYTHONPATH}
# Services Python du module
export PYTHONPATH=${ASTERSTUDY_ROOT_DIR}/lib/python2.7/site-packages/salome:${PYTHONPATH}
export PYTHONPATH=${ASTERSTUDY_ROOT_DIR}/lib/python2.7/site-packages/asterstudy:${PYTHONPATH}

# ------- end of ASTERSTUDY module ------

#------ Opencv ------
export LD_LIBRARY_PATH="${PREREQUISITES_ROOT_DIR}/Opencv-231/lib":${LD_LIBRARY_PATH}

#------- SMESH -------
SMESH_DIR=${MODULES_ROOT_DIR}/SMESH_V8_3_0
export PYTHONPATH=${SMESH_DIR}/share/salome/plugins/smesh/Verima:${PYTHONPATH}

#------- Paravis ------
export PARAVIS_DIR=${MODULES_ROOT_DIR}/PARAVIS_V8_3_0
export PV_PLUGIN_PATH="${PARAVIS_DIR}/lib/paraview":${PV_PLUGIN_PATH}
export PV_MACRO_PATH=${HOME}/.config/salome/Macros

#------ ECREVISSE  ------
export ECREVISSE_ROOT_DIR="${TOOLS_ROOT_DIR}/Ecrevisse-322"

#------ cython -----------
export CYTHON_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Cython-0232"
export PATH=${CYTHON_ROOT_DIR}/bin:${PATH}
export PYTHONPATH=${CYTHON_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}

#------- h5py ------
export PYTHONPATH=${PREREQUISITES_ROOT_DIR}/H5py-250/lib/python2.7/site-packages:${PYTHONPATH}

#---------- gmsh -------------------
export GMSHHOME="${PREREQUISITES_ROOT_DIR}/Gmsh-2110"
export PATH=${GMSHHOME}/bin:${PATH}
export LD_LIBRARY_PATH=${GMSHHOME}/lib:${LD_LIBRARY_PATH}

#------ Eficas_Nouveau -----------
export EFICAS_NOUVEAU_ROOT="${TOOLS_ROOT_DIR}/Eficas_nouveau-V8_3_0"
export EFICAS_ROOT="${TOOLS_ROOT_DIR}/Eficas_nouveau-V8_3_0"

#------- libxslt -------
export LIBXSLT_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Libxslt-1128"
export PATH=${LIBXSLT_ROOT_DIR}/bin:${PATH}
export LD_LIBRARY_PATH=${LIBXSLT_ROOT_DIR}/lib:${LD_LIBRARY_PATH}

# ------ MeshGems -------------
MESHGEMSHOME="${PREREQUISITES_ROOT_DIR}/Meshgems-245"
MESHGEMS_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Meshgems-245"

export PATH=${MESHGEMSHOME}/bin/Linux_64:$PATH
export LD_LIBRARY_PATH=${MESHGEMSHOME}/lib/Linux_64:${LD_LIBRARY_PATH}

#------ Zcracks -----------
export ZCRACKSHOME="${PREREQUISITES_ROOT_DIR}/Zcracks-287"

#---------- netgen -------------------
export NETGENHOME="${TOOLS_ROOT_DIR}/Netgen-531"
export LD_LIBRARY_PATH=${NETGENHOME}/lib:${LD_LIBRARY_PATH}

#------ ASTER module ------
export ASTER_ROOT_DIR="${MODULES_ROOT_DIR}/ASTER_20170"
# asrun
export PYTHONPATH=${ASTER_ROOT}/lib/python2.7/site-packages:${PYTHONPATH}
# Services Python du module
export PYTHONPATH=${ASTER_ROOT_DIR}/lib/python2.7/site-packages/salome:${PYTHONPATH}
# required for ASTER module (to update mesh)
export PYTHONPATH=${PYTHONPATH}:${EFICAS_ROOT}
export PYTHONPATH=${PYTHONPATH}:${EFICAS_ROOT}/UiQT5
export PYTHONPATH=${PYTHONPATH}:${EFICAS_ROOT}/Editeur
# ------- end of ASTER module ------

#------- pkgconfig ------
export PYTHONPATH=${PREREQUISITES_ROOT_DIR}/Pkgconfig-110/lib/python2.7/site-packages:${PYTHONPATH}

#---------- Homard -------------------
export HOMARD_REP_EXE="${TOOLS_ROOT_DIR}/Homard_tool-118"
export HOMARD_EXE=homard

#------ PARAVISADDONS ------
export PARAVISADDONS_ROOT_DIR="${TOOLS_ROOT_DIR}/Paravisaddons-V8_3_0"
export PV_PLUGIN_PATH=${PARAVISADDONS_ROOT_DIR}/lib:${PV_PLUGIN_PATH}
export LD_LIBRARY_PATH=${PARAVISADDONS_ROOT_DIR}/lib:${LD_LIBRARY_PATH}

#------ MUMPS ------
export LD_LIBRARY_PATH="${PREREQUISITES_ROOT_DIR}/Mumps-511_aster2/SEQ/lib":${LD_LIBRARY_PATH}

#------ code_aster - Template environment_shell ------
export ASTER_STABLE="${TOOLS_ROOT_DIR}/Code_aster_stable-v134_smeca"
if [ -d /usr/lib/atlas-base/atlas ]; then
    if [ -z "$LD_LIBRARY_PATH" ]; then
        export LD_LIBRARY_PATH=/usr/lib/atlas-base/atlas
    else
        export LD_LIBRARY_PATH=/usr/lib/atlas-base/atlas:$LD_LIBRARY_PATH
    fi
fi


#------- lxml ------
export LXML_ROOT_DIR="${PREREQUISITES_ROOT_DIR}/Lxml-340"
export PYTHONPATH=${LXML_ROOT_DIR}/lib/python2.7/site-packages:${PYTHONPATH}
